==> docfbe_2_3_39_68.zip: docfbe_2_3_39_68/source/TCFbEAdjustedWeightedSumWithAverageOfColumn.h <==
/*
    TCFbEAdjustedWeightedSumWithAverageOfColumn.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEAdjustedWeightedSumWithAverageOfColumnH
#define TCFbEAdjustedWeightedSumWithAverageOfColumnH
//---------------------------------------------------------------------------
#include "TCFbEWeightedSum.h"

#include "TCFbEToolkit.h"
#include <math.h>

#include "TCFbENeighbor.h"
//---------------------------------------------------------------------------
class TCFbEAdjustedWeightedSumWithAverageOfColumn : public TCFbEWeightedSum
{
public:
    virtual __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn(void);    // RXgN^
    __fastcall ~TCFbEAdjustedWeightedSumWithAverageOfColumn();    // fXgN^

    // vZɕKvȃLbV
    virtual void __fastcall PrepareCache(TCFbECustomTableEx* PredictionTable) {
        PredictionTable->AddChildCache(new TCFbEColumnCachedTable(PredictionTable), "Average.column", true);
    }

protected:
    bool    CashEnabled;
    double    AverageOfColumn;

    virtual void __fastcall ClearCash(void);    // LbVNA
    virtual double __fastcall GetNumerator(int NeighborIndex);    // q̒l𓾂
    virtual double __fastcall GetPredictedValue(double Numerator, double Denominator);    // \l𓾂

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_3_46_82.zip: docfbe_2_3_46_82/source/TCFbEAdjustedWeightedSumWithAverageOfColumn.h <==
/*
    TCFbEAdjustedWeightedSumWithAverageOfColumn.h    June 6, 2004.

    Copyright (C) 2003-2005 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbEAdjustedWeightedSumWithAverageOfColumnH
#define TCFbEAdjustedWeightedSumWithAverageOfColumnH
//---------------------------------------------------------------------------
#include "TCFbEWeightedSum.h"

#include "TCFbEToolkit.h"
#include <math.h>

#include "TCFbENeighbor.h"
//---------------------------------------------------------------------------
class TCFbEAdjustedWeightedSumWithAverageOfColumn : public TCFbEWeightedSum
{
public:
    virtual __fastcall TCFbEAdjustedWeightedSumWithAverageOfColumn(void);    // RXgN^
    __fastcall ~TCFbEAdjustedWeightedSumWithAverageOfColumn();    // fXgN^

    // vZɕKvȃLbV
    virtual void __fastcall PrepareCache(TCFbECustomTableEx* PredictionTable) {
        PredictionTable->AddChildCache(new TCFbEColumnCachedTable(PredictionTable), "Average.column", true);
    }

protected:
    bool    CashEnabled;
    double    AverageOfColumn;

    virtual void __fastcall ClearCash(void);    // LbVNA
    virtual double __fastcall GetNumerator(int NeighborIndex, int TargetColumnIndex);   // q̒l𓾂
    virtual double __fastcall GetPredictedValue(double Numerator, double Denominator);  // \l𓾂

private:

};
//---------------------------------------------------------------------------
#endif
